@@ -33,15 +33,7 @@ describe 'tacker::client' do
         when 'Debian'
           { :client_package_name => 'python3-tackerclient' }
         when 'RedHat'
-          if facts[:operatingsystem] == 'Fedora'
-            { :client_package_name => 'python3-tackerclient' }
-          else
-            if facts[:operatingsystemmajrelease] > '7'
-              { :client_package_name => 'python3-tackerclient' }
-            else
-              { :client_package_name => 'python-tackerclient' }
-            end
-          end
+          { :client_package_name => 'python3-tackerclient' }
         end
       end
 
